<?php

// Checking PHP Version
if (version_compare(PHP_VERSION, '7.4.0', '<')) {
    die('Payment module "Payment system VTB" requires PHP version 7.4.0 or higher.');
}

/**
 * Class name of the payment system.
 * 
 * @var string
 */
$className = 'VtbPay';

/**
 * Name of the payment system.
 * 
 * @var string
 */
$paymentName = 'Payment system VTB';

// include the standalone file for accessing e-commerce system functions
include 'standalone.php';

/**
 * Access the object types collection instance to get the internal 
 * type ID for the e-commerce payment type.
 */
$objectTypesCollection = umiObjectTypesCollection::getInstance();
$internalTypeId = $objectTypesCollection->getTypeIdByGUID('emarket-paymenttype');

/**
 * Create a new selector to search for objects within the objects 
 * collection that match the provided parameters.
 */
$sel = new selector('objects');
$sel->types('object-type')->id($internalTypeId);
$sel->where('class_name')->equals($className);
$sel->limit(0, 1);

/**
 * Check if a payment method with the given class name already exists. 
 * If not, proceed with creating a new payment method.
 */
if ($sel->length() == 0) {
    // access the objects collection instance
    $objectsCollection = umiObjectsCollection::getInstance();

    // get the parent type ID for the payment system
    $parentTypeId = $objectTypesCollection->getTypeIdByGUID('emarket-payment');

    // add a new type for the VTB payment system and get the type ID
    $typeId = $objectTypesCollection->addType($parentTypeId, $paymentName);

    // access the object type
    $objectType = $objectTypesCollection->getType($typeId);

    // add a new fields group for the settings
    $groupdId = $objectType->addFieldsGroup('settings', 'Параметры', true, true);
    $group = $objectType->getFieldsGroupByName('settings');

    // access the field types collection instance
    $fieldTypesCollection = umiFieldTypesCollection::getInstance();
    
    // get the IDs for the boolean and string field types
    $typeBoolean = $fieldTypesCollection->getFieldTypeByDataType('boolean')->getId();
    $typeString = $fieldTypesCollection->getFieldTypeByDataType('string')->getId();

    /**
     * Define the fields to be added to the settings group of the object type. 
     * Each field includes a name, type, and optional requirement flag.
     */
    $fields = [
        'vtbpay_client_id' => [
            'name' => 'Client ID',
            'type' => $typeString,
            'required' => true,
        ],
        'vtbpay_client_secret' => [
            'name' => 'Client Secret',
            'type' => $typeString,
            'required' => true,
        ],
        'vtbpay_merchant_authorization' => [
            'name' => 'Merchant-Authorization',
            'type' => $typeString
        ],
        'vtbpay_test_mode' => [
            'name' => 'Enable test mode',
            'type' => $typeBoolean
        ],
        'vtbpay_logging' => [
            'name' => 'Enable logging',
            'type' => $typeBoolean
        ]
    ];
    
    // access the fields collection instance
    $fieldsCollection = umiFieldsCollection::getInstance();

    // iterate over each field to be added
    foreach ($fields as $code => $arField) {
        $fieldId = $fieldsCollection->addField($code, $arField['name'], $arField['type']);
        $field = $fieldsCollection->getField($fieldId);
        
        if (isset($arField['guide_id'])) {
            $field->setGuideId($arField['guide_id']);
        }
        
        $isRequired = isset($arField['required']) ? $arField['required'] : false;
        $field->setIsRequired($isRequired);
        $field->setIsInSearch(false);
        $field->setIsInFilter(false);
        $field->commit();

        $group->attachField($fieldId);
    }

    // create a new internal object for the payment system
    $internalObjectId = $objectsCollection->addObject($paymentName, $internalTypeId);
    $internalObject = $objectsCollection->getObject($internalObjectId);
    
    // set the class name and payment type ID for the internal object
    $internalObject->setValue('class_name', $className); // имя класса для реализации
    $internalObject->setValue('payment_type_id', $typeId);
    $internalObject->setValue('payment_type_guid', 'emarket-payment-' . $typeId);
    $internalObject->commit();

    // set the GUID for the object type
    $objectType = $objectTypesCollection->getType($typeId);
    $objectType->setGUID($internalObject->getValue('payment_type_guid'));
    $objectType->commit();

    // print a success message
    echo '"Payment system VTB" module successfully installed. id #' . $typeId;
} else {
    // print a failure message if a payment method with the given class name already exists
    echo 'Payment method class name ' . $className . ' already exist.';
}

// delete this script after execution
unlink(__FILE__);